@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 1996-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdconf.h,v 1.2 2007/10/05 16:33:31 fredg Exp $
+//    $Id: rdconf.h,v 1.4 2008/08/04 19:05:32 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -61,31 +61,33 @@ QString RDGetShortDate(QDate);
  **/
 QString RDGetShortDayNameEN(int weekday);
 QFont::Weight RDGetFontWeight(QString);
-bool RDDetach();
+bool RDDetach(const QString &coredir);
 bool RDBool(QString);
 QString RDYesNo(bool);
 QHostAddress RDGetHostAddr();
 QString RDGetDisplay(bool strip_point=false);
-bool RDDoesRowExist(QString table,QString name,QString test,
-		   QSqlDatabase *db=0);
-bool RDDoesRowExist(QString table,QString name,unsigned test,
-		   QSqlDatabase *db=0);
-QVariant RDGetSqlValue(QString table,QString name,QString test,
-		      QString param,QSqlDatabase *db=0,bool *valid=0);
-QVariant RDGetSqlValue(QString table,QString name,unsigned test,
-		      QString param,QSqlDatabase *db=0,bool *valid=0);
-bool RDIsSqlNull(QString table,QString name,QString test,
-		QString param,QSqlDatabase *db=0);
-bool RDIsSqlNull(QString table,QString name,unsigned test,
-		QString param,QSqlDatabase *db=0);
+bool RDDoesRowExist(const QString &table,const QString &name,
+		    const QString &test,QSqlDatabase *db=0);
+bool RDDoesRowExist(const QString &table,const QString &name,unsigned test,
+		    QSqlDatabase *db=0);
+QVariant RDGetSqlValue(const QString &table,const QString &name,
+		       const QString &test,const QString &param,
+		       QSqlDatabase *db=0,bool *valid=0);
+QVariant RDGetSqlValue(const QString &table,const QString &name,unsigned test,
+		       const QString &param,QSqlDatabase *db=0,bool *valid=0);
+bool RDIsSqlNull(const QString &table,const QString &name,
+		 const QString &test,const QString &param,QSqlDatabase *db=0);
+bool RDIsSqlNull(const QString &table,const QString &name,unsigned test,
+		 const QString &param,QSqlDatabase *db=0);
 QString RDGetTimeLength(int mseconds,bool leadzero=false,bool tenths=true);
-int RDSetTimeLength(QString string);
-bool RDCopy(QString srcfile,QString destfile);
+int RDSetTimeLength(const QString &string);
+bool RDCopy(const QString &srcfile,const QString &destfile);
 #ifndef WIN32
-bool RDWritePid(QString dirname,QString filename,int owner=-1,int group=-1);
-void RDDeletePid(QString dirname,QString filename);
-bool RDCheckPid(QString dirname,QString filename);
-pid_t RDGetPid(QString pidfile);
+bool RDWritePid(const QString &dirname,const QString &filename,int owner=-1,
+		int group=-1);
+void RDDeletePid(const QString &dirname,const QString &filename);
+bool RDCheckPid(const QString &dirname,const QString &filename);
+pid_t RDGetPid(const QString &pidfile);
 #endif  // WIN32
 QString RDGetHomeDir(bool *found=0);
 bool RDTimeSynced();
