@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_user.cpp,v 1.27 2007/09/14 14:06:27 fredg Exp $
+//      $Id: edit_user.cpp,v 1.29.2.1 2008/12/09 15:45:22 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,10 +39,11 @@
 #include <rdtextvalidator.h>
 
 #include <edit_user_perms.h>
+#include <edit_feed_perms.h>
 #include <globals.h>
 
 
-EditUser::EditUser(QString user,QWidget *parent,const char *name)
+EditUser::EditUser(const QString &user,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   //
@@ -73,8 +74,8 @@ EditUser::EditUser(QString user,QWidget *parent,const char *name)
   // User Name
   //
   user_name_edit=new QLineEdit(this,"user_name_edit");
-  user_name_edit->setGeometry(100,11,80,19);
-  user_name_edit->setMaxLength(8);
+  user_name_edit->setGeometry(100,11,sizeHint().width()-110,19);
+  user_name_edit->setMaxLength(255);
   user_name_edit->setValidator(validator);
   QLabel *user_name_label=new QLabel(user_name_edit,tr("&User Name:"),this,
 				       "user_name_label");
@@ -87,7 +88,7 @@ EditUser::EditUser(QString user,QWidget *parent,const char *name)
   //
   user_full_name_edit=new QLineEdit(this,"user_full_name_edit");
   user_full_name_edit->setGeometry(100,32,sizeHint().width()-110,19);
-  user_full_name_edit->setMaxLength(64);
+  user_full_name_edit->setMaxLength(255);
   user_full_name_edit->setValidator(validator);
   QLabel *user_full_name_label=
     new QLabel(user_full_name_edit,tr("&Full Name:"),this,
@@ -123,6 +124,17 @@ EditUser::EditUser(QString user,QWidget *parent,const char *name)
   user_phone_label->setFont(font);
   user_phone_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  // Enable Web Login
+  //
+  user_web_box=new QCheckBox(this,"user_web_box");
+  user_web_box->setGeometry(20,96,15,15);
+  user_web_label=
+    new QLabel(user_web_box,tr("Allow Web Logins"),this,"user_web_label");
+  user_web_label->setGeometry(40,96,180,19);
+  user_web_label->setFont(font);
+  user_web_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+
   //
   // Change Password Button
   //
@@ -343,15 +355,66 @@ EditUser::EditUser(QString user,QWidget *parent,const char *name)
   user_config_panels_label->setFont(small_font);
   user_config_panels_label->setAlignment(AlignLeft|ShowPrefix);
 
+  //
+  // Podcast Group Priviledges
+  //
+  user_podcast_group=new QButtonGroup(tr("Podcasting Rights"),this,
+				      "user_podcast_group");
+  user_podcast_group->setGeometry(10,446,355,66);
+  user_podcast_group->setFont(font);
+
+  user_add_podcast_button=new QCheckBox(user_podcast_group,
+					"user_add_podcast_button");
+  user_add_podcast_button->setGeometry(10,21,15,15);
+  user_add_podcast_label=new QLabel(user_add_podcast_button,
+					    tr("Cre&ate Podcast"),
+					    user_podcast_group,
+					    "user_add_podcast_label");
+  user_add_podcast_label->setGeometry(30,21,150,19);
+  user_add_podcast_label->setFont(small_font);
+  user_add_podcast_label->setAlignment(AlignLeft|ShowPrefix);
+
+  user_edit_podcast_button=new QCheckBox(user_podcast_group,
+					"user_edit_podcast_button");
+  user_edit_podcast_button->setGeometry(172,21,15,15);
+  user_edit_podcast_label=new QLabel(user_edit_podcast_button,
+					    tr("E&dit Podcast"),
+					    user_podcast_group,
+					    "user_edit_podcast_label");
+  user_edit_podcast_label->setGeometry(192,21,150,19);
+  user_edit_podcast_label->setFont(small_font);
+  user_edit_podcast_label->setAlignment(AlignLeft|ShowPrefix);
+
+  user_delete_podcast_button=new QCheckBox(user_podcast_group,
+					"user_delete_podcast_button");
+  user_delete_podcast_button->setGeometry(10,42,15,15);
+  user_delete_podcast_label=new QLabel(user_delete_podcast_button,
+					    tr("Dele&te Podcast"),
+					    user_podcast_group,
+					    "user_delete_podcast_label");
+  user_delete_podcast_label->setGeometry(30,42,150,19);
+  user_delete_podcast_label->setFont(small_font);
+  user_delete_podcast_label->setAlignment(AlignLeft|ShowPrefix);
+
   //
   //  Group Permissions Button
   //
   user_assign_perms_button=new QPushButton(this,"user_assign_perms_button");
-  user_assign_perms_button->setGeometry(10,442,sizeHint().width()-20,50);
+  user_assign_perms_button->setGeometry(10,516,sizeHint().width()/2-20,50);
   user_assign_perms_button->setFont(font);
-  user_assign_perms_button->setText(tr("Assign Group Permissions"));
+  user_assign_perms_button->setText(tr("Assign Group\nPermissions"));
   connect(user_assign_perms_button,SIGNAL(clicked()),this,SLOT(groupsData()));
 
+  //
+  //  Feeds Permissions Button
+  //
+  user_assign_feeds_button=new QPushButton(this,"user_assign_feeds_button");
+  user_assign_feeds_button->
+    setGeometry(sizeHint().width()/2+10,516,sizeHint().width()/2-20,50);
+  user_assign_feeds_button->setFont(font);
+  user_assign_feeds_button->setText(tr("Assign Podcast Feed\nPermissions"));
+  connect(user_assign_feeds_button,SIGNAL(clicked()),this,SLOT(feedsData()));
+
   //
   //  Ok Button
   //
@@ -378,8 +441,9 @@ EditUser::EditUser(QString user,QWidget *parent,const char *name)
   user_name_edit->setText(user_user->name());
   user_name_edit->setReadOnly(true);
   user_full_name_edit->setText(user_user->fullName());
-  user_phone_edit->setText(user_user->phone());
   user_description_edit->setText(user_user->description());
+  user_phone_edit->setText(user_user->phone());
+  user_web_box->setChecked(user_user->enableWeb());
   if(user_user->adminConfig()) {
     user_admin_config_button->setChecked(true);
     adminToggledData(true);
@@ -402,6 +466,10 @@ EditUser::EditUser(QString user,QWidget *parent,const char *name)
     user_removefrom_log_button->setChecked(user_user->removefromLog());
     user_config_panels_button->setChecked(user_user->configPanels());
     user_modify_template_button->setChecked(user_user->modifyTemplate());
+
+    user_add_podcast_button->setChecked(user_user->addPodcast());
+    user_edit_podcast_button->setChecked(user_user->editPodcast());
+    user_delete_podcast_button->setChecked(user_user->deletePodcast());
   }
 
   //
@@ -429,7 +497,7 @@ EditUser::~EditUser()
 
 QSize EditUser::sizeHint() const
 {
-  return QSize(375,562);
+  return QSize(375,636);
 } 
 
 
@@ -445,8 +513,7 @@ void EditUser::passwordData()
 
   RDPasswd *passwd=new RDPasswd(&password,this,"passwd");
   if(passwd->exec()==0) {
-    user_password=password;
-    user_password_changed=true;
+    user_user->setPassword(password);
   }
   delete passwd;
 }
@@ -460,14 +527,25 @@ void EditUser::groupsData()
 }
 
 
+void EditUser::feedsData()
+{
+  EditFeedPerms *dialog=new EditFeedPerms(user_user,this,"dialog");
+  dialog->exec();
+  delete dialog;
+}
+
+
 void EditUser::adminToggledData(bool state)
 {
+  user_web_box->setDisabled(state);
+  user_web_label->setDisabled(state);
   user_create_carts_button->setDisabled(state);
   user_delete_carts_button->setDisabled(state);
   user_modify_carts_button->setDisabled(state);
   user_edit_audio_button->setDisabled(state);
   user_create_log_button->setDisabled(state);
   user_delete_log_button->setDisabled(state);
+  user_delete_rec_button->setDisabled(state);
   user_playout_log_button->setDisabled(state);
   user_arrange_log_button->setDisabled(state);
   user_addto_log_button->setDisabled(state);
@@ -475,6 +553,10 @@ void EditUser::adminToggledData(bool state)
   user_config_panels_button->setDisabled(state);
   user_modify_template_button->setDisabled(state);
   user_edit_catches_button->setDisabled(state);
+  user_voicetrack_log_button->setDisabled(state);
+  user_add_podcast_button->setDisabled(state);
+  user_edit_podcast_button->setDisabled(state);
+  user_delete_podcast_button->setDisabled(state);
   user_create_carts_label->setDisabled(state);
   user_delete_carts_label->setDisabled(state);
   user_modify_carts_label->setDisabled(state);
@@ -489,16 +571,21 @@ void EditUser::adminToggledData(bool state)
   user_config_panels_label->setDisabled(state);
   user_modify_template_label->setDisabled(state);
   user_edit_catches_label->setDisabled(state);
+  user_add_podcast_label->setDisabled(state);
+  user_edit_podcast_label->setDisabled(state);
+  user_delete_podcast_label->setDisabled(state);
   user_voicetrack_log_label->setDisabled(state);
   user_assign_perms_button->setDisabled(state);
+  user_assign_feeds_button->setDisabled(state);
 }
 
 
 void EditUser::okData()
 {
   user_user->setFullName(user_full_name_edit->text());
-  user_user->setPhone(user_phone_edit->text());
   user_user->setDescription(user_description_edit->text());
+  user_user->setPhone(user_phone_edit->text());
+  user_user->setEnableWeb(user_web_box->isChecked());
   user_user->setAdminConfig(user_admin_config_button->isChecked());
   user_user->setCreateCarts(user_create_carts_button->isChecked());
   user_user->setDeleteCarts(user_delete_carts_button->isChecked());
@@ -515,10 +602,9 @@ void EditUser::okData()
   user_user->setRemovefromLog(user_removefrom_log_button->isChecked());
   user_user->setConfigPanels(user_config_panels_button->isChecked());
   user_user->setModifyTemplate(user_modify_template_button->isChecked());
-
-  if(user_password_changed) {
-    user_user->setPassword(user_password);
-  }
+  user_user->setAddPodcast(user_add_podcast_button->isChecked());
+  user_user->setEditPodcast(user_edit_podcast_button->isChecked());
+  user_user->setDeletePodcast(user_delete_podcast_button->isChecked());
 
   done(0);
 }
