@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_cart.cpp,v 1.62 2007/03/14 10:26:13 fredg Exp $
+//      $Id: edit_cart.cpp,v 1.69 2008/08/04 19:05:35 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,14 +33,11 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
-#include <rconf.h>
-#include <math.h>
-#include <rcddbrecord.h>
 
+#include <rddb.h>
 #include <rd.h>
+#include <rdconf.h>
 #include <rdaudio_exists.h>
-#include <rdtextvalidator.h>
 
 #include <cdripper.h>
 #include <edit_cart.h>
@@ -88,7 +85,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   //
   // Create Default Cut
   //
-  if(new_cart) {
+  if(new_cart&&(rdcart_cart->type()==RDCart::Audio)) {
     rdcart_cart->addCut(rdlibrary_conf->defaultFormat(),
 			rdlibrary_conf->defaultSampleRate(),
 			rdlibrary_conf->defaultBitrate(),
@@ -103,11 +100,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   QFont line_edit_font=QFont("Helvetica",12,QFont::Normal);
   line_edit_font.setPixelSize(12);
 
-  //
-  // Text Validator
-  //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
-
   if(lib_cart_list_edit==NULL) {
   //
   // Cart Number
@@ -253,7 +245,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.title_edit->setGeometry(135,60,480,21);
   rdcart_controls.title_edit->setFont(line_edit_font);
   rdcart_controls.title_edit->setMaxLength(255);
-  rdcart_controls.title_edit->setValidator(validator);
   QLabel *rdcart_title_label=new QLabel(rdcart_controls.title_edit,tr("&Title:"),this,
 				       "rdcart_title_label");
   rdcart_title_label->setGeometry(10,62,120,19);
@@ -299,7 +290,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.artist_edit->setGeometry(135,84,480,21);
   rdcart_controls.artist_edit->setFont(line_edit_font);
   rdcart_controls.artist_edit->setMaxLength(255);
-  rdcart_controls.artist_edit->setValidator(validator);
   QLabel *rdcart_artist_label=new QLabel(rdcart_controls.artist_edit,tr("&Artist:"),
 					 this,"rdcart_artist_label");
   rdcart_artist_label->setGeometry(10,86,120,19);
@@ -357,7 +347,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.album_edit->setGeometry(135,134,480,21);
   rdcart_controls.album_edit->setFont(line_edit_font);
   rdcart_controls.album_edit->setMaxLength(255);
-  rdcart_controls.album_edit->setValidator(validator);
   QLabel *rdcart_album_label=new QLabel(rdcart_controls.album_edit,tr("Al&bum:"),this,
 				       "rdcart_album_label");
   rdcart_album_label->setGeometry(10,136,120,19);
@@ -371,7 +360,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.label_edit->setGeometry(135,158,480,21);
   rdcart_controls.label_edit->setFont(line_edit_font);
   rdcart_controls.label_edit->setMaxLength(64);
-  rdcart_controls.label_edit->setValidator(validator);
   QLabel *rdcart_label_label=new QLabel(rdcart_controls.label_edit,tr("Re&cord Label:"),
 					this,"rdcart_label_label");
   rdcart_label_label->setGeometry(10,160,120,19);
@@ -385,7 +373,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.client_edit->setGeometry(135,182,480,21);
   rdcart_controls.client_edit->setFont(line_edit_font);
   rdcart_controls.client_edit->setMaxLength(64);
-  rdcart_controls.client_edit->setValidator(validator);
   QLabel *rdcart_client_label=new QLabel(rdcart_controls.label_edit,tr("C&lient:"),this,
 				       "rdcart_client_label");
   rdcart_client_label->setGeometry(10,184,120,19);
@@ -399,7 +386,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.agency_edit->setGeometry(135,206,480,23);
   rdcart_controls.agency_edit->setFont(line_edit_font);
   rdcart_controls.agency_edit->setMaxLength(64);
-  rdcart_controls.agency_edit->setValidator(validator);
   QLabel *rdcart_agency_label=new QLabel(rdcart_controls.label_edit,tr("A&gency:"),this,
 				       "rdcart_agency_label");
   rdcart_agency_label->setGeometry(10,209,120,19);
@@ -413,7 +399,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.publisher_edit->setGeometry(135,231,480,23);
   rdcart_controls.publisher_edit->setFont(line_edit_font);
   rdcart_controls.publisher_edit->setMaxLength(64);
-  rdcart_controls.publisher_edit->setValidator(validator);
   QLabel *rdcart_publisher_label=new QLabel(rdcart_controls.label_edit,
 					    tr("&Publisher:"),this,
 					    "rdcart_publisher_label");
@@ -428,7 +413,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.composer_edit->setGeometry(135,256,480,23);
   rdcart_controls.composer_edit->setFont(line_edit_font);
   rdcart_controls.composer_edit->setMaxLength(64);
-  rdcart_controls.composer_edit->setValidator(validator);
   QLabel *rdcart_composer_label=new QLabel(rdcart_controls.label_edit,
 					   tr("Compos&er:"),this,
 					   "rdcart_composer_label");
@@ -443,7 +427,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_controls.user_defined_edit->setGeometry(135,281,480,21);
   rdcart_controls.user_defined_edit->setFont(line_edit_font);
   rdcart_controls.user_defined_edit->setMaxLength(255);
-  rdcart_controls.user_defined_edit->setValidator(validator);
   QLabel *rdcart_user_defined_label=
     new QLabel(rdcart_controls.label_edit,tr("&User Defined:"),this,
 	       "rdcart_user_defined_label");
@@ -496,10 +479,13 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   script_button->hide();
 
   if(lib_cart_list_edit==NULL) {
-  //
-  // Cut Widget
-  //
-  switch(rdcart_cart->type()) {
+    //
+    // Cut Widget
+    //
+    rdcart_cut_sched_box->hide();
+    rdcart_cut_sched_edit->hide();
+    rdcart_cut_sched_label->hide();
+    switch(rdcart_cart->type()) {
       case RDCart::Audio:
 	rdcart_audio_cart=new AudioCart(&rdcart_controls,rdcart_cart,
 					rdcart_import_path,new_cart,
@@ -511,7 +497,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
 		this,SLOT(cartDataChangedData()));
 	rdcart_macro_cart=NULL;
 	break;
-
+	
       case RDCart::Macro:
 	rdcart_macro_cart=new MacroCart(rdcart_cart,this,"rdcart_macro_cart");
 	rdcart_macro_cart->
@@ -522,16 +508,13 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
 	rdcart_audio_cart=NULL;
 	rdcart_controls.enforce_length_box->setDisabled(true);
 	rdcart_enforce_length_label->setDisabled(true);
-	rdcart_cut_sched_box->hide();
-	rdcart_cut_sched_edit->hide();
-	rdcart_cut_sched_label->hide();
 	rdcart_syncronous_box->show();
 	rdcart_syncronous_label->show();
 	break;
-
+	
       default:
 	break;
-  }
+    }
   }
 
   //
@@ -569,7 +552,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
       setText(QString().sprintf("%06d",rdcart_cart->number()));
     if(rdcart_group_box->count() == 0)
     {
-      QSqlQuery *q=new QSqlQuery("select NAME from GROUPS");
+      RDSqlQuery *q=new RDSqlQuery("select NAME from GROUPS");
       while(q->next()) {
 	rdcart_group_box->insertItem(q->value(0).toString());
       }
@@ -601,7 +584,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
     if(lib_cart_list_edit==NULL) {
       rdcart_average_length_edit->
 	setText(QString().sprintf("%s",
-				  (const char *)RGetTimeLength(rdcart_cart->averageLength())));
+				  (const char *)RDGetTimeLength(rdcart_cart->averageLength())));
     }
     rdcart_controls.forced_length_edit->
       setTime(QTime().addMSecs(rdcart_cart->forcedLength()));
@@ -659,7 +642,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   else {//multi edit
     if(rdcart_group_box->count() == 0) {
       rdcart_group_box->insertItem("");
-      QSqlQuery *q=new QSqlQuery("select NAME from GROUPS");
+      RDSqlQuery *q=new RDSqlQuery("select NAME from GROUPS");
       while(q->next()) {
         rdcart_group_box->insertItem(q->value(0).toString());
       }
@@ -699,11 +682,16 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_start_date_edit->setReadOnly(!modification_allowed);
   rdcart_end_date_edit->setReadOnly(!modification_allowed);
   if(lib_cart_list_edit==NULL) {
-  rdcart_average_length_edit->
-    setReadOnly((!modification_allowed)||
+    rdcart_average_length_edit->
+      setReadOnly((!modification_allowed)||
 		(!rdcart_controls.enforce_length_box->isChecked()));
+    if(rdcart_cart->type()!=RDCart::Audio) {
+      rdcart_controls.enforce_length_box->setDisabled(true);
+    }
+    else {
+    rdcart_controls.enforce_length_box->setEnabled(modification_allowed);
+    }
   }
-  rdcart_controls.enforce_length_box->setEnabled(modification_allowed);
   if(!modification_allowed) {
     rdcart_controls.forced_length_edit->hide();
     rdcart_forced_length_ledit->show();
@@ -713,7 +701,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
 
 QSize EditCart::sizeHint() const
 {
-  return QSize(640,690);
+  return QSize(640,750);
 } 
 
 
@@ -731,7 +719,7 @@ void EditCart::scriptData()
 void EditCart::lengthChangedData(unsigned len)
 {
   if(!rdcart_syncronous_box->isChecked()) {
-    rdcart_average_length_edit->setText(RGetTimeLength(len));
+    rdcart_average_length_edit->setText(RDGetTimeLength(len));
     rdcart_cart->calculateAverageLength(&rdcart_length_deviation);
   }
 }
@@ -769,7 +757,7 @@ void EditCart::okData()
 			    QTime().msecsTo(rdcart_controls.
 					    forced_length_edit->time()));
   rdcart_cart->
-    setAverageLength(RSetTimeLength(rdcart_average_length_edit->text()));
+    setAverageLength(RDSetTimeLength(rdcart_average_length_edit->text()));
   if(rdcart_controls.enforce_length_box->isChecked()) {
     rdcart_cart->
       setForcedLength(QTime().msecsTo(rdcart_controls.forced_length_edit->time()));
@@ -777,7 +765,7 @@ void EditCart::okData()
   }
   else {
     rdcart_cart->
-      setForcedLength(RSetTimeLength(rdcart_average_length_edit->text()));
+      setForcedLength(RDSetTimeLength(rdcart_average_length_edit->text()));
     rdcart_cart->setEnforceLength(false);
   }
   rdcart_cart->setPreservePitch(rdcart_preserve_pitch_button->isChecked());
@@ -868,16 +856,16 @@ void EditCart::okData()
 void EditCart::cancelData()
 {
   unsigned len;
-  if(lib_cart_list_edit==NULL) {
-  len=rdcart_cart->calculateAverageLength(&rdcart_length_deviation);
-  rdcart_cart->setLengthDeviation(rdcart_length_deviation);
-  if(!rdcart_controls.enforce_length_box->isChecked()) {
-    rdcart_cart->setForcedLength(len);
-  }
-  rdcart_cart->updateLength(rdcart_controls.enforce_length_box->isChecked(),
-			    QTime().msecsTo(rdcart_controls.
-					    forced_length_edit->time()));
+  if((lib_cart_list_edit==NULL)&&(rdcart_cart->type()==RDCart::Audio)) {
+    len=rdcart_cart->calculateAverageLength(&rdcart_length_deviation);
+    rdcart_cart->setLengthDeviation(rdcart_length_deviation);
+    if(!rdcart_controls.enforce_length_box->isChecked()) {
+      rdcart_cart->setForcedLength(len);
     }
+    rdcart_cart->updateLength(rdcart_controls.enforce_length_box->isChecked(),
+			      QTime().msecsTo(rdcart_controls.
+					      forced_length_edit->time()));
+  }
   done(-1);
 }
 
@@ -889,7 +877,7 @@ void EditCart::forcedLengthData(bool state)
   if(state) {
     rdcart_controls.forced_length_edit->
       setTime(QTime().
-	      addMSecs(RSetTimeLength(rdcart_average_length_edit->text())));
+	      addMSecs(RDSetTimeLength(rdcart_average_length_edit->text())));
   }
 }
 
@@ -901,7 +889,7 @@ void EditCart::asyncronousToggledData(bool state)
   }
   else {
     rdcart_average_length_edit->
-      setText(RGetTimeLength(rdcart_macro_cart->length()));
+      setText(RDGetTimeLength(rdcart_macro_cart->length()));
   }
 }
 
@@ -911,7 +899,7 @@ void EditCart::cartDataChangedData()
   if(!rdcart_controls.enforce_length_box->isChecked()) {
     rdcart_average_length_edit->
       setText(QString().sprintf("%s",
-	  (const char *)RGetTimeLength(rdcart_cart->calculateAverageLength())));
+	  (const char *)RDGetTimeLength(rdcart_cart->calculateAverageLength())));
   }
 }
 
@@ -932,7 +920,7 @@ bool EditCart::ValidateLengths()
 					   time()));
   QString sql=QString().sprintf("select LENGTH from CUTS where CART_NUMBER=%u",
 				rdcart_cart->number());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     if((q->value(0).toInt()>maxlen)||(q->value(0).toInt()<minlen)) {
       delete q;
