@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: vguest.cpp,v 1.27 2007/11/12 18:43:29 fredg Exp $
+//      $Id: vguest.cpp,v 1.30 2008/10/01 14:43:59 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -168,6 +168,13 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
 	    reconnect_mapper,SLOT(map()));
   }
 
+  //
+  // Interval OneShots
+  //
+  vguest_gpio_oneshot=new RDOneShot(this);
+  connect(vguest_gpio_oneshot,SIGNAL(timeout(void *)),
+	  this,SLOT(gpioOneshotData(void*)));
+
   //
   // Initialize the connection
   //
@@ -214,7 +221,7 @@ void VGuest::processCommand(RDMacro *cmd)
 	   (cmd->arg(1).toUInt()>vguest_displays_engine_nums.size())) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
-	  LogLine("*** not enough arguments ***");
+	  LogLine(RDConfig::LogWarning,"*** not enough vGuest arguments ***");
 	  return;
 	}
 	if((vguest_displays_engine_nums[cmd->arg(1).toInt()-1]<0)||
@@ -222,7 +229,7 @@ void VGuest::processCommand(RDMacro *cmd)
 	   (vguest_displays_surface_nums[cmd->arg(1).toInt()-1]<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
-	  LogLine("*** invalid hex parameters ***");
+	  LogLine(RDConfig::LogWarning,"*** invalid vGuest hex parameters ***");
 	  return;
 	}
 	label=cmd->rollupArgs(5).left(VGUEST_MAX_TEXT_LENGTH);
@@ -267,18 +274,20 @@ void VGuest::processCommand(RDMacro *cmd)
 	break;
 
       case RDMacro::GO:
-	if((cmd->arg(1).toInt()<1)||(cmd->arg(1).toInt()>vguest_gpos)||
-	   (cmd->arg(2).toInt()<0)||(cmd->arg(2).toInt()>1)||
-	   (cmd->arg(3).toInt()<0)) {
+	if(((cmd->arg(1).toString().lower()!="i")&&
+	    (cmd->arg(1).toString().lower()!="o"))||
+	   (cmd->arg(2).toInt()<1)||(cmd->arg(2).toInt()>vguest_gpos)||
+	   (cmd->arg(3).toInt()<0)||(cmd->arg(3).toInt()>1)||
+	   (cmd->arg(4).toInt()<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
 	  return;
 	}
-	if(cmd->arg(3).toInt()>0) {
+	if(cmd->arg(4).toInt()>0) {
 	  cmd_byte=0x51;
 	}
 	else {
-	  switch(cmd->arg(2).toInt()) {
+	  switch(cmd->arg(3).toInt()) {
 	      case 0:
 		cmd_byte=0x53;
 		break;
@@ -288,10 +297,10 @@ void VGuest::processCommand(RDMacro *cmd)
 		break;
 	  }
 	}
-	if((vguest_relays_engine_nums[cmd->arg(1).toInt()-1]<0)||
-	   (vguest_relays_device_nums[cmd->arg(1).toInt()-1]<0)||
-	   (vguest_relays_surface_nums[cmd->arg(1).toInt()-1]<0)||
-	   (vguest_relays_relay_nums[cmd->arg(1).toInt()-1]<0)) {
+	if((vguest_relays_engine_nums[cmd->arg(2).toInt()-1]<0)||
+	   (vguest_relays_device_nums[cmd->arg(2).toInt()-1]<0)||
+	   (vguest_relays_surface_nums[cmd->arg(2).toInt()-1]<0)||
+	   (vguest_relays_relay_nums[cmd->arg(2).toInt()-1]<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
 	  return;
@@ -299,25 +308,32 @@ void VGuest::processCommand(RDMacro *cmd)
 	switch(cmd_byte) {
 	    case 0x51:
 	      sprintf(buffer,"\x02\x07\x51%c%c%c%c%c%c",
-		      vguest_relays_engine_nums[cmd->arg(1).toInt()-1],
-		      vguest_relays_device_nums[cmd->arg(1).toInt()-1]>>8,
-		      vguest_relays_device_nums[cmd->arg(1).toInt()-1]&0xFF,
-		      vguest_relays_surface_nums[cmd->arg(1).toInt()-1],
-		      vguest_relays_relay_nums[cmd->arg(1).toInt()-1],
-		      cmd->arg(3).toInt()/50);
+		      vguest_relays_engine_nums[cmd->arg(2).toInt()-1],
+		      vguest_relays_device_nums[cmd->arg(2).toInt()-1]>>8,
+		      vguest_relays_device_nums[cmd->arg(2).toInt()-1]&0xFF,
+		      vguest_relays_surface_nums[cmd->arg(2).toInt()-1],
+		      vguest_relays_relay_nums[cmd->arg(2).toInt()-1],
+		      cmd->arg(4).toInt()/50);
 	      SendCommand(buffer,9);
+	      emit gpiChanged(vguest_matrix,cmd->arg(2).toInt()-1,true);
+	      emit gpoChanged(vguest_matrix,cmd->arg(2).toInt()-1,true);
+	      vguest_gpio_oneshot->start((void *)(cmd->arg(2).toInt()-1),2000);
 	      break;
 
 	    case 0x52:
 	    case 0x53:
 	      sprintf(buffer,"\x02\x06%c%c%c%c%c%c",
 		      cmd_byte,
-		      vguest_relays_engine_nums[cmd->arg(1).toInt()-1],
-		      vguest_relays_device_nums[cmd->arg(1).toInt()-1]>>8,
-		      vguest_relays_device_nums[cmd->arg(1).toInt()-1]&0xFF,
-		      vguest_relays_surface_nums[cmd->arg(1).toInt()-1],
-		      vguest_relays_relay_nums[cmd->arg(1).toInt()-1]);
+		      vguest_relays_engine_nums[cmd->arg(2).toInt()-1],
+		      vguest_relays_device_nums[cmd->arg(2).toInt()-1]>>8,
+		      vguest_relays_device_nums[cmd->arg(2).toInt()-1]&0xFF,
+		      vguest_relays_surface_nums[cmd->arg(2).toInt()-1],
+		      vguest_relays_relay_nums[cmd->arg(2).toInt()-1]);
 	      SendCommand(buffer,8);
+	      emit gpiChanged(vguest_matrix,cmd->arg(2).toInt()-1,
+			      cmd->arg(3).toInt());
+	      emit gpoChanged(vguest_matrix,cmd->arg(2).toInt()-1,
+			      cmd->arg(3).toInt());
 	}
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
@@ -354,7 +370,8 @@ void VGuest::connectedData(int id)
 void VGuest::connectionClosedData(int id)
 {
   int interval=GetHoldoff();
-  LogLine(QString().sprintf("Connection to vGuest device at %s:%d closed, attempting reconnect, holdoff = %d mS",
+  LogLine(RDConfig::LogNotice,QString().
+	  sprintf("Connection to vGuest device at %s:%d closed, attempting reconnect, holdoff = %d mS",
 			    (const char *)vguest_ipaddress[id].toString(),
 			    vguest_ipport[id],interval));
   vguest_reconnect_timer[id]->start(interval,true);
@@ -405,7 +422,7 @@ void VGuest::errorData(int err,int id)
   switch((QSocket::Error)err) {
       case QSocket::ErrConnectionRefused:
 	interval=GetHoldoff();
-	LogLine(QString().sprintf(
+	LogLine(RDConfig::LogNotice,QString().sprintf(
 	 "Connection to vGuest device at %s:%d refused, attempting reconnect, holdoff = %d mS",
 	 (const char *)vguest_ipaddress[id].toString(),
 	 vguest_ipport[id],interval));
@@ -413,14 +430,14 @@ void VGuest::errorData(int err,int id)
 	break;
 
       case QSocket::ErrHostNotFound:
-	LogLine(QString().sprintf(
+	LogLine(RDConfig::LogWarning,QString().sprintf(
 	  "Error on connection to vGuest device at %s:%d: Host Not Found",
 	  (const char *)vguest_ipaddress[id].toString(),
 	  vguest_ipport[id]));
 	break;
 
       case QSocket::ErrSocketRead:
-	LogLine(QString().sprintf(
+	LogLine(RDConfig::LogWarning,QString().sprintf(
 	  "Error on connection to vGuest device at %s:%d: Socket Read Error",
 	  (const char *)vguest_ipaddress[id].toString(),
 	  vguest_ipport[id]));
@@ -429,6 +446,13 @@ void VGuest::errorData(int err,int id)
 }
 
 
+void VGuest::gpioOneshotData(void *data)
+{
+  emit gpiChanged(vguest_matrix,(long)data,false);
+  emit gpoChanged(vguest_matrix,(long)data,false);
+}
+
+
 void VGuest::SendCommand(char *str,int len)
 {
   // LogLine(QString().sprintf("SENT: %s",(const char *)RenderCommand(str,len)));
@@ -477,7 +501,7 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 	switch(cmd[3]) {
 	    case 0x0A:  // Valid connection
 	    case 0x14:
-	      LogLine(QString().sprintf(
+	      LogLine(RDConfig::LogInfo,QString().sprintf(
 			"connection to vGuest device at %s:%d established",
 			(const char *)vguest_ipaddress[id].toString(),
 			vguest_ipport[id]));
@@ -485,7 +509,7 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 
 	    case 0x0B:  // Invalid Username
 	    case 0x15:
-	      LogLine(QString().sprintf(
+	      LogLine(RDConfig::LogWarning,QString().sprintf(
 	      "connection to vGuest device at %s:%d refused: username invalid",
 			(const char *)vguest_ipaddress[id].toString(),
 			vguest_ipport[id]));
@@ -495,7 +519,7 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 
 	    case 0x0C:  // Invalid Password
 	    case 0x16:
-	      LogLine(QString().sprintf(
+	      LogLine(RDConfig::LogWarning,QString().sprintf(
 	      "connection to vGuest device at %s:%d refused: password invalid",
 			(const char *)vguest_ipaddress[id].toString(),
 			vguest_ipport[id]));
@@ -505,7 +529,7 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 
 	    case 0x0D:  // No vGuest Permission
 	    case 0x17:
-	      LogLine(QString().sprintf(
+	      LogLine(RDConfig::LogWarning,QString().sprintf(
 	  "connection to vGuest device at %s:%d refused: no vGuest permission",
 			(const char *)vguest_ipaddress[id].toString(),
 			vguest_ipport[id]));
@@ -515,7 +539,7 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 
 	    case 0x0E:  // No Profile
 	    case 0x18:
-	      LogLine(QString().sprintf(
+	      LogLine(RDConfig::LogWarning,QString().sprintf(
 	   "connection to vGuest device at %s:%d refused: no profile assigned",
 			(const char *)vguest_ipaddress[id].toString(),
 			vguest_ipport[id]));
@@ -529,10 +553,12 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 	if((linenum=GetRelay(0xFF&cmd[3],256*(0xFF&cmd[4])+(0xFF&cmd[5]),
 			     0xFF&cmd[6],0xFF&cmd[7]))>=0) {
 	  emit gpiChanged(vguest_matrix,linenum,true);
+	  emit gpoChanged(vguest_matrix,linenum,true);
 	}
 	else {
-	  LogLine(QString().sprintf("unhandled vGuest command received: %s",
-				    (const char *)RenderCommand(cmd,len)));
+	  LogLine(RDConfig::LogDebug,QString().
+		  sprintf("unhandled vGuest command received: %s",
+			  (const char *)RenderCommand(cmd,len)));
 	}
 	break;
 
@@ -540,10 +566,12 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 	if((linenum=GetRelay(0xFF&cmd[3],256*(0xFF&cmd[4])+(0xFF&cmd[5]),
 			     0xFF&cmd[6],0xFF&cmd[7]))>=0) {
 	  emit gpiChanged(vguest_matrix,linenum,false);
+	  emit gpoChanged(vguest_matrix,linenum,false);
 	}
 	else {
-	  LogLine(QString().sprintf("unhandled vGuest command received: %s",
-				    (const char *)RenderCommand(cmd,len)));
+	  LogLine(RDConfig::LogDebug,QString().
+		  sprintf("unhandled vGuest command received: %s",
+			  (const char *)RenderCommand(cmd,len)));
 	}
 	break;
 
@@ -557,8 +585,9 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 	break;
 
       default:
-	LogLine(QString().sprintf("unrecognized vGuest command received: %s",
-				  (const char *)RenderCommand(cmd,len)));
+	LogLine(RDConfig::LogDebug,QString().
+		sprintf("unrecognized vGuest command received: %s",
+			(const char *)RenderCommand(cmd,len)));
 	break;
   }
 }
